@@ -93,6 +93,12 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
     if(class(data) != "dispRity") {
         ## Data must be a matrix
         check.class(data, "matrix")
+
+        ## Check whether it is a distance matrix
+        if(check.dist.matrix(data, just.check = TRUE)) {
+            warning("boot.matrix is applied on what seems to be a distance matrix.\nThe resulting matrices won't be distance matrices anymore!", call. = FALSE)
+        }
+
         ## Creating the dispRity object
         dispRity_object <- make.dispRity(data = data)
         #dispRity_object$subsets$origin$elements <- seq(1:nrow(data))
@@ -105,10 +111,10 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
         ## With the correct names
         data_names <- names(data)
         if(is.null(data_names)) {
-            stop(paste(as.expression(match_call$data), "must be either a matrix or an output from the chrono.subsets or custom.subsets functions."), call. = FALSE)
+            stop.call(match_call$data, " must be either a matrix or an output from the chrono.subsets or custom.subsets functions.")
         } else {
             if(data_names[[1]] != "matrix" | data_names[[2]] != "call" | data_names[[3]] != "subsets") {
-                stop(paste(as.expression(match_call$data), "must be either a matrix or an output from the chrono.subsets or custom.subsets functions."), call. = FALSE)
+                stop.call(match_call$data, "must be either a matrix or an output from the chrono.subsets or custom.subsets functions.")
             }
         }
 
@@ -132,8 +138,7 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
 
     if(!missing(prob)) {
         if(probabilistic_subsets) {
-            stop(paste0(as.expression(match_call$data), " was generated using a gradual time-slicing (", data$call$subsets[2], ").\nThe prob option is not yet implemented for this case."), call. = FALSE)
-            #warning(paste0(match_call$data, " was generated using a gradual time-slicing (", data$call$subsets[2], ").\nThe probabilities generated by chrono.subsets() are multiplied by prob." ))
+            stop.call(match_call$data, paste0(" was generated using a gradual time-slicing (", data$call$subsets[2], ").\nThe prob option is not yet implemented for this case."))
         } else {
             probabilistic_subsets <- TRUE
             ## Check if prob is the right class
@@ -142,7 +147,7 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
             ## Check if it has attributes
             prob_names <- attributes(prob)
             if(is.null(prob_names)) {
-                stop("prob argument must have names (vector) or dimnames (matrix) attributes.", call. = FALSE)
+                stop.call("", "prob argument must have names (vector) or dimnames (matrix) attributes.")
             } else {
                 if(is.null(prob_names$names)) {
                     prob_names <- prob_names$dimnames[[1]]
@@ -155,7 +160,7 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
             if(class_prob == "matrix") {
                 prob <- as.vector(prob)
                 if(length(prob) !=  length(prob_names)) {
-                    stop("prob argument must be a matrix with one column only.", call. = FALSE)
+                    stop.call("", "prob argument must be a matrix with one column only.")
                 } else {
                     names(prob) <- prob_names 
                 }
@@ -163,7 +168,7 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
 
             ## Check the names
             if(!all(prob_names %in% rownames(data$matrix))) {
-                stop(paste0("prob argument contains elements not present in ", as.expression(match_call$data), "."), call. = FALSE)
+                stop.call(msg.pre = "prob argument contains elements not present in ", call =match_call$data, msg = ".")
             } else {
                 ## Check if they are any names missing
                 missing_rows <- rownames(data$matrix) %in% prob_names
@@ -176,7 +181,7 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
 
             ## Check the type of probability
             if(any(prob < 0)) {
-                stop("Probabilities given to prob argument must be positive.", call. = FALSE)
+                stop.call("", "Probabilities given to prob argument must be positive.")
             }
 
             ## Check if probabilities are weights
@@ -278,9 +283,13 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
         ## Else must be a single numeric value (proportional)
         check.class(dimensions, "numeric", " must be a proportional threshold value.")
         check.length(dimensions, 1, " must be a proportional threshold value.", errorif = FALSE)
-        if(dimensions < 0) stop("Number of dimensions to remove cannot be less than 0.")
+        if(dimensions < 0) {
+            stop.call("", "Number of dimensions to remove cannot be less than 0.")
+        }
         if(dimensions < 1) dimensions <- round(dimensions * ncol(data$matrix))
-        if(dimensions > ncol(data$matrix)) stop("Number of dimensions to remove cannot be more than the number of columns in the matrix.", call. = FALSE)
+        if(dimensions > ncol(data$matrix)) {
+            stop.call("", "Number of dimensions to remove cannot be more than the number of columns in the matrix.")
+        }
         data$call$dimensions <- dimensions
     } else {
         data$call$dimensions <- ncol(data$matrix)
