@@ -106,6 +106,7 @@ dispRity <- function(data, metric, dimensions, ..., verbose = FALSE){#, parallel
     
     ## Saving the call
     match_call <- match.call()
+    dots <- list(...)
 
     # warning("DEBUG") ; return(match_call)
 
@@ -117,7 +118,7 @@ dispRity <- function(data, metric, dimensions, ..., verbose = FALSE){#, parallel
     } else {
         ## Making sure matrix exist
         if(is.null(data$matrix)) {
-            stop(paste(as.expression(match_call$data), "must contain a matrix."), call. = FALSE)
+            stop.call(match_call$data, " must contain a matrix.")
         }
         ## Make sure dimensions exist in the call
         if(is.null(data$call$dimensions)) {
@@ -126,11 +127,11 @@ dispRity <- function(data, metric, dimensions, ..., verbose = FALSE){#, parallel
     }
 
     ## Get the metric list
-    metrics_list <- get.dispRity.metric.handle(metric, match_call)
+    metrics_list <- get.dispRity.metric.handle(metric, match_call, ...)
 
     ## Stop if data already contains disparity and metric is not level1
     if(!is.null(metrics_list$level3.fun) && length(data$call$disparity$metric) != 0) {
-        stop("Impossible to apply a dimension-level 3 metric on disparity data.", call. = FALSE)
+        stop.call("", "Impossible to apply a dimension-level 3 metric on disparity data.")
     }
 
     ## Dimensions
@@ -138,7 +139,9 @@ dispRity <- function(data, metric, dimensions, ..., verbose = FALSE){#, parallel
         ## Else must be a single numeric value (proportional)
         silent <- check.class(dimensions, c("numeric", "integer"), " must be a number or proportion of dimensions to keep.")
         check.length(dimensions, 1, " must be a number or proportion of dimensions to keep.", errorif = FALSE)
-        if(dimensions < 0) stop("Number of dimensions to remove cannot be less than 0.", call. = FALSE)
+        if(dimensions < 0) {
+            stop.call("", "Number of dimensions to remove cannot be less than 0.")
+        }
         if(dimensions < 1) dimensions <- round(dimensions * ncol(data$matrix))
         if(dimensions > ncol(data$matrix)) {
             warning(paste0("Dimension number too high: set to ", ncol(data$matrix), "."))
@@ -259,7 +262,22 @@ dispRity <- function(data, metric, dimensions, ..., verbose = FALSE){#, parallel
     data$disparity <- disparity
 
     ## Update the call
-    data$call$disparity$metrics <- c(data$call$disparity$metrics, match_call$metric)
+    data$call$disparity$metrics$name <- c(data$call$disparity$metrics$name, match_call$metric)
+    if(!is.null(data$call$disparity$metrics$fun)) {
+        data$call$disparity$metrics$fun <- list(unlist(data$call$disparity$metrics$fun, recursive = FALSE), metric)
+    } else {
+        data$call$disparity$metrics$fun <- metric
+    }
+
+    if(!is.null(data$call$disparity$metrics$args)) {
+        if(length(dots) != 0) {
+            data$call$disparity$metrics$args <- list(unlist(data$call$disparity$metrics$args, recursive = FALSE), dots)
+        }
+    } else {
+        if(length(dots) != 0) {
+            data$call$disparity$metrics$args <- dots
+        }
+    }
 
     return(data)
 }
