@@ -19,7 +19,7 @@
 #' \itemize{
 #'   \item \code{ellipse.volume}: calculates the ellipsoid volume of a matrix.
 #'      \itemize{
-#'          \item WARNING: this function uses the matrix' eigen values. These eigen values are only estimated correctly from MDS or PCO (PCoA) ordinations (e.g. \code{\link[stats]{cmdscale}}, \code{\link[ape]{pcoa}}). For any other type of matrix, the eigen values needs to be provided manually through \code{ellipse.volume(matrix, eigen.value = my_val)} (or \code{dispRity(matrix, metric = ellipse.volume, eigen.value = my_val)}).
+#'          \item WARNING: this function calculates the matrix' eigen values from the matrix as \code{abs(apply(var(matrix),2, sum))} (which is equivalent to \code{eigen(var(matrix))$values} but faster). These values are the correct eigen values for any matrix but differ from the ones output from \code{\link[stats]{cmdscale}} and \code{\link[ape]{pcoa}} because these later have their eigen values multiplied by the number of elements - 1 (i.e. \code{abs(apply(var(matrix),2, sum)) * nrow(matrix) -1 }). Specific eigen values can always be provided manually through \code{ellipse.volume(matrix, eigen.value = my_val)} (or \code{dispRity(matrix, metric = ellipse.volume, eigen.value = my_val)}).
 #'      }
 #'   \item \code{convhull.surface}: calculates the convex hull hypersurface of a matrix (calls \code{convhulln(x, options = "FA")$area}).
 #'   \item \code{convhull.volume}: calculates the convex hull hypervolume of a matrix (calls \code{convhulln(x, options = "FA")$vol}).
@@ -83,9 +83,7 @@
 #' 
 #' ## Ellipsoid volume of a matrix
 #' ellipse.volume(dummy_matrix)
-#' ## WARNING: this is only valid without eigen vaues for MDS/PCO matrices.
-#' ## Use the correct eigen values for other types of matrices:
-#' ## Ordination
+#' ## Calculating the same volume with provided eigen values
 #' ordination <- prcomp(dummy_matrix)
 #' ## Calculating the ellipsoid volume
 #' ellipse.volume(ordination$x, eigen.value = ordination$sdev^2)
@@ -167,7 +165,7 @@ dimension.level2.fun <- function(matrix, ...) {
 }
 
 dimension.level1.fun <- function(X, ...) {
-    cat("Dimension level 12 functions implemented in dispRity:\n")
+    cat("Dimension level 1 functions implemented in dispRity:\n")
     cat("?ellipse.volume\n")
     cat("?convhull.surface\n")
     cat("?convhull.volume\n")
@@ -242,10 +240,9 @@ ellipse.volume <- function(matrix, eigen.value) {
     ## Initialising the variables
     ncol_matrix <- ncol(matrix)
 
-    ## The eigenvalue is equal to the sum of the variance/covariance within each axis
-    ## multiplied by the maximum number of dimensions (k-1) - ONLY WORKS FOR MDS OR PCO!
+    ## The eigenvalue is equal to the sum of the variance/covariance within each axis (* nrow(matrix) as used in pco/pcoa)
     if(missing(eigen.value)) {
-        eigen.value <- abs(apply(var(matrix),2, sum)*(nrow(matrix)-1))
+        eigen.value <- abs(apply(var(matrix),2, sum)) # * (nrow(matrix) - 1)
     } else {
         eigen.value <- eigen.value[1:ncol_matrix]
     }
