@@ -69,7 +69,7 @@ fill.dispRity <- function(data) {
     if(!is.null(data$matrix)) {
         check.class(data$matrix, "matrix")
     } else {
-        stop("dispRity object contains no matrix. Use:\nmake.dispRity(data = my_matrix)", call. = FALSE)
+        stop.call("", "dispRity object contains no matrix. Use:\nmake.dispRity(data = my_matrix)")
     }
 
     ## Dimensions
@@ -120,6 +120,12 @@ matrix.dispRity <- function(data, subsets, rarefaction, bootstrap){
 
     ## Sanitizing
     check.class(data, "dispRity")
+
+    ## Add the dimensions if missing
+    if(is.null(data$call$dimensions)) {
+        data$call$dimensions <- ncol(data$matrix)
+    }
+
     if(missing(subsets)) {
         return(data$matrix)
     } else {
@@ -226,15 +232,20 @@ extract.dispRity <- function(data, subsets, observed = TRUE, rarefaction = FALSE
     # SANITIZING
     #----------------------
     
+    match_call <- match.call()
+
     ## Data
     check.class(data, "dispRity")
     ## Data must have disparity values
     if(is.null(data$call$disparity)) {
-        stop("dispRity object does not contain disparity values.", call. = FALSE)
+        stop.call(match_call$data, " does not contain disparity values.")
     }
 
     ## Observed
     check.class(observed, "logical")
+    if(!observed && is.null(data$call$bootstrap)) {
+        stop.call("", "Only observed values are available. Set observed = TRUE.")
+    }
 
     ## subsets
     if(missing(subsets)) {
@@ -248,9 +259,11 @@ extract.dispRity <- function(data, subsets, observed = TRUE, rarefaction = FALSE
         check.class(rarefaction, c("numeric", "integer"))
         check.length(rarefaction, 1, errorif = FALSE, msg = "Only one rarefaction level can be used.")
         if(data$call$bootstrap[[3]][1] != "full" & any(is.na(match(rarefaction, data$call$bootstrap[[3]])))) {
-            stop("Rarefaction level not found.", call. = FALSE)
+            stop.call("", "Rarefaction level not found.")
+        }
+        if(observed) {
+            warning("Observed value cannot be extract if rarefaction is not FALSE.")
         }
-        if(observed) {warning("Observed value cannot be extract if rarefaction is not FALSE.")}
     } 
 
     ## Get the disparity values
@@ -307,10 +320,12 @@ extract.dispRity <- function(data, subsets, observed = TRUE, rarefaction = FALSE
 
 rescale.dispRity <- function(data, center = FALSE, scale = FALSE, use.all = TRUE, ...) {
 
+    match_call <- match.call()
+
     ## data
     check.class(data, "dispRity")
     if(is.null(data$call$disparity)) {
-        stop("dispRity object does not contain disparity values.", call. = FALSE)
+        stop.call(match_call$data, "does not contain disparity values.")
     }
 
     ## Get the whole distribution
@@ -383,23 +398,27 @@ rescale.dispRity <- function(data, center = FALSE, scale = FALSE, use.all = TRUE
 sort.dispRity <- function(x, decreasing = FALSE, sort, ...) {
     data <- x
 
+    match_call <- match.call()
+
     ## Sanitizing
 
     ## data
     check.class(data, "dispRity")
     ## Initialising subsets length variable
     length_subsets <- length(data$subsets)
-    if(length_subsets == 1) stop("The data contains no subsets.", call. = FALSE)
+    if(length_subsets == 1) {
+        stop.call(match_call$x, " contains no subsets.")
+    }
 
     ## decreasing
     check.class(decreasing, "logical")
 
     ## sort
     if(!missing(sort)) {
-        check.class(sort, "numeric")
+        check.class(sort, c("numeric", "integer"))
         check.length(sort, length_subsets, " must be the same length as the number of subsets in data.")
         if(all.equal(sort(sort), seq(from = 1, to = length_subsets)) != TRUE) {
-            stop(paste("Sort argument can only contain unique numbers between 1 and ", length_subsets, ".", sep = ""), call. = FALSE)
+            stop.call("", paste0("The sort argument can only contain unique numbers between 1 and ", length_subsets, "."))
         }
     } else {
         if(decreasing == FALSE) sort <- seq(from = 1, to = length_subsets)
@@ -512,31 +531,35 @@ combine.subsets <- function(data, subsets) {
         ## Subsamples is the minimum per subsets
         clean_data <- TRUE
         if(subsets > nrow(data$matrix)) {
-            stop(paste("Minimum sample size (", subsets, ") cannot be greater than the number of elements in the matrix (", nrow(data$matrix), ").", sep = ""), call. = FALSE)
+            stop.call("", paste0("Minimum sample size (", subsets, ") cannot be greater than the number of elements in the matrix (", nrow(data$matrix), ")."))
         }
 
     } else {
 
         if(length(data$subsets) < length(subsets)) {
-            stop(paste(as.expression(match_call$data), "does not contain enough subsets!"), call. = FALSE)
+            stop.call(match_call$data, " does not contain enough subsets.")
         }
 
         clean_data <- FALSE
         ## Must be at least two long
-        if(length(subsets) < 2) stop("Subsamples argument must contain at least two values.", call. = FALSE)
+        if(length(subsets) < 2) {
+            stop.call("", "subsets argument must contain at least two values.")
+        }
         ## Must not contain duplicates
-        if(length(subsets) != length(unique(subsets))) stop("Subsamples argument must not contain duplicates.", call. = FALSE)
+        if(length(subsets) != length(unique(subsets))) {
+            stop.call("", "subsets argument must not contain duplicates.")
+        }
         if(subsets_class == "character") {
             ## Must be present in the subsets names
             matches <- subsets %in% names(data$subsets)
             if(any(matches == FALSE)) {
-                stop(paste(paste(subsets[!matches], collapse = " and "), "don't match with any of the subset names in", match_call$data), call. = FALSE)
+                stop.call(msg.pre = paste0(paste(subsets[!matches], collapse = " and "), " don't match with any of the subset names in "), call = match_call$data, msg = ".")
             } else {
                 subsets <- match(subsets, names(data$subsets))
             }
         } else {
             if(any(subsets > length(data$subsets))) {
-                stop(paste("subsets", paste(subsets[which(subsets > length(data$subsets))], collapse = " and "), "don't match with any of the subsets in", match_call$data), call. = FALSE)
+                stop.call(msg.pre = paste0("subsets", paste(subsets[which(subsets > length(data$subsets))], collapse = " and "), " don't match with any of the subsets in "), call = match_call$data, msg = ".")
             }
         }
     }
@@ -635,10 +658,12 @@ size.subsets <- function(data) {
 
 extinction.subsets <- function(data, extinction, lag = 1, names = FALSE, as.list = FALSE) {
 
+    match_call <- match.call()
+
     ## data
     check.class(data, "dispRity")
     if(length(data$subsets) < 2) {
-        stop("data has no subsets. Use the chrono.subsets to generate some.", call. = FALSE)
+        stop.call(match_call$data, " has no subsets. Use the chrono.subsets to generate some.")
     }
 
     ## extinction
@@ -647,14 +672,14 @@ extinction.subsets <- function(data, extinction, lag = 1, names = FALSE, as.list
     ## check if the extinction is within the range
     data_range <- range(as.numeric(unlist(strsplit(names(data$subsets), split = " - "))))
     if(extinction < data_range[1] || extinction > data_range[2]) {
-        stop(paste0("extinction argument must be a numeric value between ", data_range[1], " and ", data_range[2], "."), call. = FALSE)
+        stop.call("", paste0("extinction argument must be a numeric value between ", data_range[1], " and ", data_range[2], "."))
     }
 
     check.class(lag, c("numeric", "integer"))
     check.length(lag, 1, errorif = FALSE, msg = "lag argument must be a single numeric argument.")
     lag <- round(lag)
     if(lag < 1) {
-        stop("lag argument must be at least 1.", call. = FALSE)
+        stop.call("", "lag argument must be at least 1.")
     }
 
     check.class(names, "logical")
