@@ -58,14 +58,14 @@ make.metric <- function(fun, ..., silent = FALSE) {
 
     ## Testing the metric
     test <- NULL
-    op <- options(warn = 2)
+    op <- options(warn = -1)
     test <- try(fun(matrix, ...), silent = TRUE)
     #try(test <- fun(matrix), silent = TRUE) ; warning("DEBUG")
     options(op)
 
-    if(any(test == "try-error") || is.na(test)) {
+    if(any("try-error" %in% test) || any(is.na(test))) {
         if(silent != TRUE) {
-            stop(paste("The provided metric function generated an error or a warning!\nDoes the following work?\n    ", as.expression(match_call$fun),"(matrix(rnorm(20), 5,4))\nThe problem may also come from the optional arguments (...) in ", as.expression(match_call$fun), ".", sep = ""), call. = FALSE)
+            stop.call(match_call$fun, paste0("(matrix(rnorm(20), 5,4))\nThe problem may also come from the optional arguments (...) in ", as.expression(match_call$fun), "."), "The provided metric function generated an error or a warning!\nDoes the following work?\n    ")
         }
     } else {
 
@@ -74,7 +74,7 @@ make.metric <- function(fun, ..., silent = FALSE) {
         ##########
 
         ## If class is matrix -> level3.fun
-        if(class(test) == "matrix") {
+        if(class(test)[1] == "matrix") {
             fun_type <- "level3"
             if(silent != TRUE) {
                 cat(paste(as.expression(match_call$fun)," outputs a matrix object.\n", as.expression(match_call$fun), " is detected as being a dimension-level 3 function.", sep = ""))
@@ -82,7 +82,7 @@ make.metric <- function(fun, ..., silent = FALSE) {
             }
         } else {
             ## If class is numeric
-            if(class(test) == "numeric") {
+            if(class(test)[1] == "numeric") {
                 ## If only one value -> level1.fun
                 if(length(test) == 1) {
                     fun_type <- "level1"
@@ -99,7 +99,7 @@ make.metric <- function(fun, ..., silent = FALSE) {
             } else {
                 ## Function provides a wrong output
                 if(silent != TRUE) {
-                    stop(paste("The provided function did not output a matrix or a numeric vector!\nDoes the following output a matrix or a numeric vector?\n    ", as.expression(match_call$fun),"(matrix(rnorm(20), 5,4))\nThe problem may also come from the optional arguments (...).", sep = ""), call. = FALSE)
+                    stop.call(match_call$fun, paste0("(matrix(rnorm(20), 5,4))\nThe problem may also come from the optional arguments (...) in ", as.expression(match_call$fun), "."), "The provided metric function generated an error or a warning!\nDoes the following work?\n    ")
                 }
             }
         }
