@@ -75,13 +75,14 @@ null.test <- function(data, replicates = 100, null.distrib, null.args = NULL, nu
 
     ## Sanitizing
     check.class(data, "dispRity")
-    if(is.null(data$call$disparity)) stop("Disparity has not been calculated yet.\nUse the dispRity() function to do so.\n", sep = "", call. = FALSE)
+    if(is.null(data$call$disparity)) {
+        stop.call("", "Disparity has not been calculated yet.\nUse the dispRity() function to do so.")
+    }
 
     ## is_distribution?
     is_distribution <- ifelse(length(data$disparity[[1]]$elements) != 1, TRUE, FALSE)
     if(is_distribution) {
-        stop(paste("null.test cannot take disparity distributions yet.\nTry averaging disparity to a dimension-level 1 using:\n",
-            paste("  ", as.expression(match_call$data), " <- dispRity(", as.expression(match_call$data), ", metric = median)\n", sep = "")), call. = FALSE)
+        stop.call(match_call$data, paste0(" <- dispRity(", as.expression(match_call$data), ", metric = median)\n"), msg.pre = "null.test cannot take disparity distributions yet.\nTry averaging disparity to a dimension-level 1 using:\n    ")
     }
 
     ## replicates
@@ -97,15 +98,19 @@ null.test <- function(data, replicates = 100, null.distrib, null.args = NULL, nu
 
     ## NULL TESTING
 
+    ## Handle the disparity metrics
+    metric <- get.metric.from.call(data, what = "fun")
+    args <- get.metric.from.call(data, what = "args")
+
     ## Generating the null models
     if(length(data$subsets) != 1) {
         ## Subdivide the data per subsets
         sub_data <- lapply(as.list(seq(1:length(data$subsets))), function(X) get.subsets(data, X))
         ## Apply the data to all subsets
-        null_models_results <- lapply(sub_data, make.null.model, replicates, null.distrib, null.args, null.cor, null.scree, scale)
+        null_models_results <- lapply(sub_data, make.null.model, replicates, null.distrib, null.args, null.cor, null.scree, scale, metric, args)
     } else {
         ## Apply the data to one subsets
-        null_models_results <- make.null.model(data, replicates, null.distrib, null.args, null.cor, null.scree, scale)
+        null_models_results <- make.null.model(data, replicates, null.distrib, null.args, null.cor, null.scree, scale, metric, args)
     }
 
     ## testing the null hypothesis
@@ -113,6 +118,8 @@ null.test <- function(data, replicates = 100, null.distrib, null.args = NULL, nu
         ## Apply the randtest to one subsets
         test_out  <- ade4::as.randtest(obs = summary(data, digits = 10)[, 3], sim = null_models_results, alter = alter, ...)
         # test_out  <- ade4::as.randtest(obs = summary(data, digits = 10)[,3], sim = null_models_results, alter = alter)
+        ## Adding the simulated data
+        test_out$sim <- null_models_results
         ## Store it as a list of one element (to be consistent for S3 methods)
         test_out <- list(test_out)
     } else {
@@ -120,6 +127,10 @@ null.test <- function(data, replicates = 100, null.distrib, null.args = NULL, nu
         summary_observed <- as.list(summary(data, digits = 10)[, 3])
         test_out <- mapply(ade4::as.randtest, null_models_results, summary_observed, MoreArgs = list(alter = alter, ...), SIMPLIFY = FALSE)
         # test_out <- mapply(ade4::as.randtest, null_models_results, summary_observed, MoreArgs = list(alter = alter), SIMPLIFY = FALSE) ; warning("DEBUG")
+        ## Adding the simulated data
+        for(subset in 1:length(data$subsets)) {
+            test_out[[subset]]$sim <- null_models_results[[subset]]
+        }
         ## Attributing the subsets names
         names(test_out) <- names(data$subsets)
     }
