@@ -44,6 +44,9 @@
 #source("sanitizing.R")
 
 pair.plot <- function(data, what, col = c("black", "white"), legend = FALSE, binary, diag, add, lower = TRUE, ...){
+
+    match_call <- match.call()
+
     #Sanitizing
     #data
     if(class(data) == "matrix") {
@@ -67,7 +70,7 @@ pair.plot <- function(data, what, col = c("black", "white"), legend = FALSE, bin
         results <- data[, which(colnames(data) == what)]
     }
     if(length(results) == 0) {
-        stop("What argument was not found in the data.frame.", call. = FALSE)
+        stop.call(match_call$what, " was not found in the data.frame.")
     }
 
     #col
@@ -94,7 +97,7 @@ pair.plot <- function(data, what, col = c("black", "white"), legend = FALSE, bin
         if(class(diag) == "character") {
             check.length(diag, 1, " must be a single numeric character or 'max' or 'min'.")
             if(diag != "max" && diag != "min") {
-                stop("Diag argument must be a single numeric character or 'max' or 'min'.", call. = FALSE)
+                stop.call("", "diag argument must be a single numeric character or 'max' or 'min'.")
             }     
         } else {
             check.class(diag, "numeric")
@@ -109,10 +112,10 @@ pair.plot <- function(data, what, col = c("black", "white"), legend = FALSE, bin
     if(!missing(add)) {
         check.length(add, 1, " must be a single 'numeric' or 'character' string.")
         if(class(add) != "character" && class(add) != "numeric") {
-            stop("Add must be a single 'numeric' or 'character' string.", call. = FALSE)
+            stop.call("", "add must be a single 'numeric' or 'character' string.")
         }
         if(missing(binary)) {
-            stop("A threshold for binary argument must be provided.", call. = FALSE)
+            stop.call("", "A threshold for binary argument must be provided.")
         }
         #Deactivate legend
         legend <- FALSE
