@@ -83,68 +83,35 @@ check.method <- function(argument, all_arguments, msg, condition = all) {
     }
 }
 
-## Transforming a tree to binary with no zero length branches.
-# bin.tree <- function(tree){
-#     if(!is.binary.tree(tree)) {
-#         tree <- multi2di(tree)
-#         warning('tree is now binary.' , call.=FALSE)
-#     }
-#     ## Null branch length?
-#     if(any(tree$edge.length == 0)){
-#         tree$edge.length[which(tree$edge.length == 0)] <- min(tree$edge.length[-which(tree$edge.length == 0)])*0.01
-#         warning('New branches length generated are set to 1% of the minimum branch length.' , call. = FALSE)
-#     }
-#     return(tree)
-# }
+## Checking if a matrix is a distance matrix
+check.dist.matrix <- function(matrix, method, just.check = FALSE) {
 
-## Replacing a value to be NA
-# replace.na <- function(x, y="?") {
-#     x[which(x == y)]  <-  NA
-#     return(x)
-# }
+    ## Is distance
+    was_dist <- FALSE
 
-# make.nexus <- function(matrix, header, ordering, weights) {
-#     ## SANITIZING
-#     ## matrix
-#     check.class(matrix, "matrix")
+    ## Is the matrix square?
+    if(dim(matrix)[1] == dim(matrix)[2] &&
+       all(diag(matrix) == 0) &&
+       all(matrix[upper.tri(matrix)] == matrix[rev(lower.tri(matrix))])) {
 
-#     ## header
-#     if(missing(header)) {
-#         header <- NA
-#     } else {
-#         check.class(header, "character")
-#         check.length(header, 1, " must be a single character string.", errorif=FALSE)
-#     }
+        ## It was a distance matrix!
+        was_dist <- TRUE
+    }
 
-#     ## ordering
-#     if(missing(ordering)) {
-#         ordering <- rep("unord", ncol(matrix))
-#     } else {
-#         check.class(ordering, "character")
-#         check.length(ordering, ncol(matrix), " must be the same length as the matrix.", errorif = FALSE)
-#         options(warn = -1)
-#         if(any(ordering != c("unord", "ord"))) {
-#             stop("Ordering vector must contain only 'unord' or/and 'ord' values.")
-#         }
-#         options(warn = 0)
-#     }
+    if(just.check) {
+        ## Simply return the check
+        return(was_dist)
+    } else {
+        ## Return a matrix
+        if(was_dist) {
+            return(list(stats::as.dist(matrix), "was_dist" = TRUE))
+        } else {
+            return(list(vegan::vegdist(matrix, method = method), "was_dist" = FALSE))
+        }
+    }
+}
 
-#     ## weights
-#     if(missing(weights)) {
-#         weights <- rep(1, ncol(matrix))
-#     } else {
-#         check.class(weights, "integer")
-#         check.length(weights, ncol(matrix), " must be the same length as the matrix.", errorif = FALSE)
-#     }
-
-#     ## BUILD THE NEXUS OBJECT
-#     nexus <- list()
-#     nexus$header <- header
-#     nexus$matrix <- matrix
-#     nexus$ordering <- ordering
-#     nexus$weights <- weights
-#     nexus$max.vals <- apply(matrix, 2, max, na.rm=TRUE)
-#     nexus$min.vals <- apply(matrix, 2, min, na.rm=TRUE)
-
-#     return(nexus)
-# }
\ No newline at end of file
+## Stop with call message wrapper function
+stop.call <- function(call, msg, msg.pre = "") {
+    stop(paste0(msg.pre, as.expression(call), msg), call. = FALSE)
+}
